Web radio expandable collection with advanced features in a browser of your choice.
Give your radio a name, description and a nice picture.

 * each radio has a display
 * server/app runs in a terminal window
 * written in Python and Java script
 * runs on Flask and SQLite

Installation help:
Python Interpreter software must be installed.

	xxx Linux xxx:
	--------------
	pip3 install eisenradio
	python3 -m eisenradio.app


	xxx Windows xxx:
	----------------
	pip install eisenradio
	
	python -m eisenradio.app
	or
	Double Click /eisenradio/app.py
	or
	create a shortcut
	pip show eisenradio ,to get the package location
	create a shortcut on your desktop to the target script 'app.py', <Location:path to>/eisenradio/app.py
	
	recording needs a folder with write access
	use 'Save' from navigation bar to choose a folder